@@ -38,30 +38,35 @@
 #'
 #' library(inti)
 #' library(gsheet)
-#'
+#' 
 #' url <- paste0("https://docs.google.com/spreadsheets/d/"
 #'               , "15r7ZwcZZHbEgltlF6gSFvCTFA-CFzVBWwg3mFlRyKPs/"
-#'               , "edit#gid=883914570")
+#'               , "edit#gid=172957346")
 #' # browseURL(url)
-#'
+#' 
 #' fb <- gsheet2tbl(url)
-#' fb %>% plot_smr()
-#'
-#' fb %>%
-#'   plot_smr(type = "line"
-#'            , x = "genotipo"
-#'            , y = "lfa"
-#'            , xlab = "test"
-#'            , ylab = "gran"
-#'            , glab = "legend"
-#'            , xrotation = c(45, 0.5, 0.5)
-#'            , ylimits = c(0, 15000, 3000)
-#'            )
-#'
+#' 
+#' 
+#' yrs <- yupana_analysis(data = fb
+#'                        , response = "hi"
+#'                        , model_factors = "geno*treat"
+#'                        , comparison = c("geno", "treat")
+#'                        )
+#' 
+#' yrs$meancomp %>% plot_smr(type = "bar"
+#'                           , x = "geno"
+#'                           , y = "hi"
+#'                           , group = "treat"
+#'                           , ylimits = c(0, 1, 0.1)
+#'                           , opt = "theme_minimal()"
+#'                           , color = c("brown", "blue", "black")
+#'                           , sig = "sig"
+#'                           ) +
+#'                            facet_grid(.~ treat)
+#' 
 #' }
 #' 
 
-
 plot_smr <- function(data
                      , type = NULL
                      , x = NULL
@@ -71,144 +76,16 @@ plot_smr <- function(data
                      , ylab = NULL
                      , glab = NULL
                      , ylimits = NULL
-                     , xrotation = NULL
+                     , xrotation = c(0, 0.5, 0.5)
                      , xtext = NULL
                      , gtext = NULL
-                     , legend = NULL
+                     , legend = "top"
                      , sig = NULL
                      , error = NULL
                      , color = TRUE
                      , opt = NULL
                      ) {
   
-if(FALSE) {
-  
-  data <- mc$comparison
-  
-  data <- fb
-  
-  var <- list(type.e = NULL
-              , x.e = NULL
-              , y.e = NULL
-              , group.e = NULL
-              , xlab.e = NULL
-              , ylab.e = NULL
-              , glab.e = NULL
-              , ylimits.e = NULL
-              , xrotation.e = NULL
-              , xtext.e = NULL
-              , gtext.e = NULL
-              , legend.e = NULL
-              , sig.e = NULL
-              , error.e = NULL
-              , color.e = TRUE
-              , opt.e = NULL
-              ) 
-  
-  list2env(var, environment())
-  
-}
-  
-type.e <- x.e <- y.e <- group.e <- xlab.e <- ylab.e <- glab.e <- NULL
-ylimits.e <- xrotation.e <- xtext.e <- gtext.e <- legend.e <- NULL
-sig.e <- error.e <- color.e <- opt.e  <-  NULL
-  
-# arguments ---------------------------------------------------------------
-
-arg_dt <- data %>%
-  as.data.frame() %>%
-  select(starts_with("{") | ends_with("}")) %>%
-  rename_with(~ gsub("\\{|\\}", "", .) ) 
-
-# -------------------------------------------------------------------------
-
-  if(length(arg_dt) >= 2) {
-
-  graph_opts <- arg_dt %>%
-    select(.data$arguments, .data$values) %>%
-    drop_na(.data$arguments) %>% 
-    mutate(arguments = paste0(.data$arguments, ".e")) %>% 
-    deframe() %>% 
-    as.list()
-  
-  list2env(graph_opts, environment())
-
-  if("colors" %in% names(arg_dt)) {
-
-    plot_color <- arg_dt %>%
-      select(colors) %>%
-      drop_na() %>% 
-      deframe()
-    
-    color <- TRUE
-    
-  } 
-
-  }
-
-# -------------------------------------------------------------------------
-
-if(is.null(x)) x <- x.e 
-if(is.null(y)) y <- y.e
-
-if(is.null(type) & is.na(type.e)) {
-  type <- "bar"
-} else {
-  type <- type.e 
-  }
-
-if(is.null(group) & is.na(group.e)) group <- x else group <- group.e
-
-if(is.null(xlab) & is.na(xlab.e)) xlab <- NULL else xlab <- xlab.e
-if(is.null(ylab) & is.na(ylab.e)) ylab <- NULL else ylab <- ylab.e
-if(is.null(glab) & is.na(glab.e)) glab <- NULL else glab <- glab.e
-
-if(is.null(legend) & is.na(legend.e)) legend <- "top" else legend <- legend.e
-if(is.null(sig) & is.na(sig.e)) sig <- NULL else sig <- sig.e
-if(is.null(error) & is.na(error.e)) error <- NULL else error <- error.e
-
-if(is.null(xtext) & is.na(xtext.e)) {
-  xtext <- NULL
-} else {
-  xtext <- xtext.e %>%
-    strsplit(split = ",") %>% 
-    unlist()
-}
-
-if(is.null(gtext) & is.na(gtext.e)) {
-  gtext <- NULL
-} else {
-  gtext <- gtext.e %>%
-    strsplit(split = ",") %>% 
-    unlist()
-} 
-
-if(is.null(xrotation) & is.na(xrotation.e)) {
-  xrotation <- c(0, 0.5, 0.5)
-  } else {
-    xrotation <- xrotation.e %>%
-      strsplit(split = "[*]") %>% 
-      unlist() %>% 
-      as.numeric()
-    }
-
-if(is.null(ylimits) & is.na(ylimits.e)) {
-  ylimits <- NULL
-} else {
-  ylimits <- ylimits.e %>% 
-    strsplit(split = "[*]") %>% 
-    unlist() %>% 
-    as.numeric()
-  }
-
-if(is.null(opt) & is.na(opt.e)) {
-  opt <- NA
-} else {
-  opt <- opt.e %>% 
-    gsub(' +', " ", .) %>%
-    gsub("[\r\n]", "", .) 
-} 
-
 # match args --------------------------------------------------------------
 
 legend <- match.arg(legend, c("top", "left", "right", "bottom", "none"))
@@ -217,27 +94,34 @@ type <- match.arg(type, c("barra", "linea"))
 if(!c(x %in% colnames(data))) stop("colum no exist")
 if(!c(y %in% colnames(data))) stop("colum no exist")
 
+# -------------------------------------------------------------------------
+
+if(is.null(group)) {group <- x}
+
+
 # graph-color -------------------------------------------------------------
 
-color_full <- colorRampPalette(
-  c("#86CD80"   # green
-    , "#F4CB8C" # orange
-    , "#F3BB00" # yellow
-    , "#0198CD" # blue
-    , "#FE6673" # red
-  ))(length(data[[group]] %>% unique()))
-
-color_gray <- gray.colors(n =  data[[group]] %>% unique() %>% length()
-                          , start = 0.8
-                          , end = 0.3) 
-
-if(length(plot_color) != 0) {
+if (isTRUE(color)) {
   
-  color_full <- plot_color
+  color <- colorRampPalette(
+    c("#86CD80"   # green
+      , "#F4CB8C" # orange
+      , "#F3BB00" # yellow
+      , "#0198CD" # blue
+      , "#FE6673" # red
+    ))(length(data[[group]] %>% unique()))
   
-  color_gray <- plot_color
+} else if (isFALSE(color)) {
   
-} 
+  color <- gray.colors(n =  data[[group]] %>% unique() %>% length()
+                       , start = 0.8
+                       , end = 0.3) 
+  
+} else {
+  
+  color <- color
+  
+}
 
 # sci-labels --------------------------------------------------------------
 
@@ -247,7 +131,7 @@ if ( !is.null(xlab) ) {
     gsub(pattern = " ", "~", .)
   xlab <- eval(expression(parse(text = xlab)))
   
-} else { xlab <- x }
+}
 
 if ( !is.null(ylab) ) { #
   
@@ -256,7 +140,7 @@ if ( !is.null(ylab) ) { #
   
   ylab <- eval(expression(parse(text = ylab)))
   
-} else { ylab <- y }
+}
 
 if ( !is.null(glab) ) {
   
@@ -264,7 +148,7 @@ if ( !is.null(glab) ) {
     gsub(pattern = " ", "~", .)
   glab <- eval(expression(parse(text = glab)))
   
-} else { glab <- group }
+} 
 
 # type --------------------------------------------------------------------
 
@@ -281,7 +165,8 @@ if(type == "barra") {
   plot <- plotdt %>% 
     ggplot(., aes(x = .data[[x]]
                   , y = .data[[y]]
-                  , fill = .data[[group]])) +
+                  , fill = .data[[group]])
+           ) +
     
     geom_col(
       position = position_dodge2()
@@ -316,16 +201,16 @@ if(type == "barra") {
           , colour = "black"
           , vjust = -0.5
           , hjust = 0.5
-          , angle = 0) 
+          , angle = 0
+          , size = 2.5
+          ) 
     } +
-    scale_fill_manual(values = if(isFALSE(color)) color_gray else color_full
+    scale_fill_manual(values = color
                       , labels = if(!is.null(gtext)) gtext else waiver()) 
 }
 
-
 # line plot ---------------------------------------------------------------
 
-
 if (type == "linea") {
   
   plot <- plotdt %>% 
@@ -367,12 +252,14 @@ if (type == "linea") {
           , colour = "black"
           , vjust = -0.5
           , hjust = 0.5
-          , angle = 0) 
+          , angle = 0
+          , size = 2.5
+          ) 
     } +
     
     scale_color_manual(
       labels = if(!is.null(gtext)) gtext else waiver()
-      , values = if(isFALSE(color)) color_gray else color_full
+      , values = color
     ) + 
     scale_linetype_discrete(labels = if(!is.null(gtext)) gtext else waiver()) +
     scale_shape_discrete(labels = if(!is.null(gtext)) gtext else waiver())
@@ -394,22 +281,16 @@ graph <- plot +
 
 layers <- 'graph +
   theme_minimal() +
-  theme(
-    panel.background = element_rect(fill = "transparent")
-    , plot.background = element_rect(fill = "transparent")
-    , panel.grid.major = element_blank()
-    , panel.grid.minor = element_blank()
+  theme(legend.position = legend
+    , panel.border = element_rect(colour = "black", fill=NA)
+    , panel.background = element_rect(fill = "transparent")
     , legend.background = element_rect(fill = "transparent")
-    , legend.box.background = element_rect(fill = "transparent")
-    , legend.position = legend
     , axis.text.x = element_text(angle = xrotation[1]
                                  , hjust= xrotation[2]
                                  , vjust = xrotation[3])
-  )'
+    )'
 
-
-
-if(is.na(opt)) {
+if(is.null(opt)) {
   eval(parse(text = layers)) 
 } else {
   eval(parse(text = paste(layers, opt, sep = " + ")))
