@@ -1,24 +1,6 @@
 ## ----setup, include=FALSE-----------------------------------------------------
-library(inti)
-library(knitr)
-
-knitr::opts_chunk$set(
-    fig.align = "center" # Center images in the export file
-  , out.width = "98%" # Figure width in html
-  , echo = TRUE # Avoid print code in the export file
-  , message = FALSE # Avoid print messages in the export file
-  , warning = FALSE # Avoid print messages in the export file
-  , collapse = TRUE
-  , comment = "#>"
-  )
-
-options(
-    OutDec= "." # Use "." instead of "," in the decimal values
-  , scipen = 99 # Avoid use "6e-04"
-  , knitr.kable.NA = "" # NA values will appear as empty cell
-  , knitr.table.format = "pipe" # Format for export tables
-  , citr.use_betterbiblatex = FALSE # For zotero addin 
-  ) 
+source("http://inkaverse.com/docs.r")
+knitr::opts_chunk$set(echo = TRUE)
 
 ## ---- echo=FALSE--------------------------------------------------------------
 tibble(
@@ -28,7 +10,7 @@ tibble(
   ) %>% 
   kable(caption = "Differentes heritability calculation")
 
-## ----pkgs---------------------------------------------------------------------
+## ----pkgs, echo=TRUE----------------------------------------------------------
 library(inti)
 library(agridat)
 
@@ -38,11 +20,10 @@ library(agridat)
             , trait = "yield"
             , gen.name = "gen"
             , rep.n = 3
-            , fix.model = "rep + (1|rep:block) + gen"
-            , ran.model = "rep + (1|rep:block) + (1|gen)"
+            , ran.model = "1 + rep + (1|rep:block) + (1|gen)"
+            , fix.model = "0 + rep + (1|rep:block) + gen"
             , emmeans = TRUE
             , plot_diag = TRUE
-            , plot_dots = "rep"
             , outliers.rm = TRUE
             )
 
