@@ -4,19 +4,21 @@
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/yupanapro/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2021-04-08
+#> date .: 2021-04-29
 # -------------------------------------------------------------------------
 
-suppressPackageStartupMessages({
-  library(inti)
-  library(bslib)
-  library(metathis)
-  library(googlesheets4)
-  library(googleAuthR)
-  library(shinydashboard)
-  library(cowplot)
-  library(corrplot)
-  library(tidyverse)
-  library(FactoMineR)
-})
+# -------------------------------------------------------------------------
+# packages ----------------------------------------------------------------
+# -------------------------------------------------------------------------
+
+library(inti)
+library(bslib)
+library(metathis)
+library(googlesheets4)
+library(googleAuthR)
+library(shinydashboard)
+library(cowplot)
+library(corrplot)
+library(tidyverse)
+library(FactoMineR)
 
