@@ -4,7 +4,7 @@
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/yupanapro/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2021-04-24
+#> date .: 2021-05-24
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
@@ -13,7 +13,8 @@
 
 #> devtools::install_github("flavjack/inti")
 
-source("pkgs.R")
+source("msgs.R")
+suppressPackageStartupMessages({source("pkgs.R")})
 
 options("googleAuthR.scopes.selected" = c("https://www.googleapis.com/auth/spreadsheets"
                                           , "https://www.googleapis.com/auth/userinfo.email"
@@ -45,27 +46,40 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
                     , includeCSS("www/custom.css")
                     , tags$head(includeHTML(("www/analytics.html")))
                     , tags$head(tags$link(rel="shortcut icon"
-                                          , href="https://flavjack.github.io/inti/reference/figures/yupana.png")),
+                                          , href="https://flavjack.github.io/inti/logo.png")),
                     
                     meta() %>%
                       meta_social(
                         title = "Yupana",
                         description = "Yupana: platform for statistical data analysis",
-                        url = "https://flavjack.shinyapps.io/tarpuy/",
-                        image = "https://flavjack.github.io/inti/reference/figures/yupana.png",
-                        image_alt = "quipolab.com"
+                        url = "https://flavjack.shinyapps.io/yupanapro/",
+                        image = "https://flavjack.github.io/inti/img/yupana.png",
+                        image_alt = "inkaverse.com"
                       )
                     
                     , fluidRow(
 
                       column(width = 1,
+                             
+                             HTML('
+              <div id=footer style="width:100%; margin:auto;">
+              <div style="display:inline-block; width:100%">
+              <p style="text-align:center">
+              <a target="_blank" href="https://inkaverse.com/articles/yupana.html">
+              <img src="https://flavjack.github.io/inti/img/yupana.png" style="height:80px" title="Yupana"></a>
+              <span style="display:block;"><small>Yupana</small></span>
+              </p></div>
+              </div>
+                    '),
+              
+              br(),
 
                              HTML('
             <div id=footer style="width:100%; margin:auto;">
             <div style="display:inline-block; width:100%">
             <p style="text-align:center">
             <a target="_blank" href="https://flavjack.github.io/inti/index.html">
-            <img src="https://flavjack.github.io/inti/reference/figures/biologia.png" style="height:50px" title="flozano"></a>
+            <img src="https://flavjack.github.io/inti/logo.png" style="height:80px" title="flozano"></a>
             <span style="display:block;"><small>project</small></span>
             </p></div>
             </div>
@@ -161,29 +175,35 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
                              fluidRow(
 
                                box(title = h5("Fieldbook data")
-                                   , width = 3
+                                   , width = 2
                                    , solidHeader = T,
 
-                                   textInput(inputId = "fieldbook_gsheet"
-                                             , label = NULL
-                                             , value = "fb"
-                                             , placeholder = "Sheet name"
-                                   )
+                                   uiOutput("fieldbook_gsheet")
+                                   
                                ),
-
-                               box(title = h5("Fieldbook summary")
-                                   , width = 3
+                               
+                               box(title = h5("Last factor")
+                                   , width = 2
                                    , solidHeader = T,
-
-                                   textInput(inputId = "fbsmrvars_gsheet"
+                                 
+                                   uiOutput("fb_last_factor")
+                                 
+                               ),
+                               
+                               box(title = h5("Model factors (optional)")
+                                   , width = 6
+                                   , solidHeader = T,
+                                   
+                                   textInput(inputId = "fb_model_factors"
                                              , label = NULL
-                                             , value = "fbsm"
-                                             , placeholder = "Sheet name"
-                                   )
+                                             , width = "100%"
+                                             , placeholder = "e.g. block + factor1*factor2"
+                                             )
+                                   
                                ),
 
                                box(title = div(h5("Open GS"), align = "center")
-                                   , width = 6
+                                   , width = 2
                                    , solidHeader = T,
 
                                    div(
@@ -273,7 +293,7 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
               <div style="display:inline-block; width:100%">
               <p style="text-align:center">
               <a target="_blank" href="https://www.youtube.com/playlist?list=PLSQMdOu57lj9sTx5Dbff9O0g6KCU4pwCQ">
-              <img src="https://flavjack.github.io/inti/reference/figures/youtube.png" style="height:60px" title="demo"></a>
+              <img src="https://flavjack.github.io/inti/img/youtube.png" style="height:60px" title="demo"></a>
               <span style="display:block;"><small>demo</small></span>
               </p></div>
               </div>
@@ -286,7 +306,7 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
               <div style="display:inline-block; width:100%">
               <p style="text-align:center">
               <a target="_blank" href="https://flavjack.shinyapps.io/tarpuy/">
-              <img src="https://flavjack.github.io/inti/reference/figures/tarpuy.png" style="height:80px" title="tarpuy"></a>
+              <img src="https://flavjack.github.io/inti/img/tarpuy.png" style="height:80px" title="tarpuy"></a>
               <span style="display:block;"><small>Tarpuy</small></span>
               </p></div>
               </div>
@@ -298,168 +318,440 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
 
            ),
 
-           tabPanel("Fieldbook",
-
-# Yupana Fieldbook --------------------------------------------------------
+# Exploratory -------------------------------------------------------------
 # -------------------------------------------------------------------------
 
-                    fluidRow(
-
-                      column(2,
-
-                             radioButtons(inputId = "fb_preview_opt"
-                                          , label = "Modules"
-                                          , choices = c("Summary"
-                                                        , "Reshape")
-                                          , inline = TRUE
-
-                             ),
-
-                             uiOutput("fb_modules"),
-
-                             br(),
-
-                             ),
-
-                      column(width = 10,
-
-                             uiOutput("fieldbook_preview")
-
-                      ),
-
-                     )
+tabPanel("Exploratory",
+         
+         fluidRow(
+           
+           column(2,
+                  
+                  fixedRow(
+                    
+                    column(12, 
+                           
+                           selectInput(
+                             inputId = "raw_type"
+                             , label = "Type"
+                             , choices = c("boxplot")
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("raw_response"),
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("raw_x"),
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("raw_group"),
+                           
+                    ),
+                    
+                    column(6, 
+                           
+                           textInput(
+                             inputId ="raw_ylimits"
+                             , label = "Y limits"
+                             , placeholder = "0*100*20"
+                           )
+                           
+                    ),
+                    
+                    column(6, 
+                           
+                           textInput(
+                             inputId ="raw_xrotation"
+                             , label = "X rotation"
+                             , value = "0*0.5*0.5"
+                             , placeholder = "angle*h*v"
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           textInput(
+                             inputId = "raw_dimension"
+                             , label = "Dimensions (W*H*dpi)"
+                             , placeholder = "W*H*dpi"
+                             , value = "20*10*100"
+                           )
+                           
+                    )
+                    
+                  )
+                  
+           ),
+           
+           column(8,
+                  
+                  uiOutput("plot_raw"),
+                  
+           ),
+           
+           column(2,
+                  
+                  fixedRow(
+                    
+                    column(6, 
+                           
+                           selectInput(
+                             inputId ="raw_color"
+                             , label = "Color"
+                             , choices = c("yes", "no")
+                           )
+                           
+                    ),   
+                    
+                    column(6, 
+                           
+                           selectInput(
+                             inputId = "raw_legend"
+                             , label = "Legend"
+                             , choices = c("top", "bottom", "left", "right", "none")
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           textInput(
+                             inputId ="raw_ylab"
+                             , label = "Y label"
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           textInput(
+                             inputId ="raw_xlab"
+                             , label = "X label"
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           textInput(
+                             inputId ="raw_glab"
+                             , label = "Group label"
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           textInput(
+                             inputId ="raw_gtext"
+                             , label = "Group brake labels (,)"
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           textInput(
+                             inputId ="raw_xtext"
+                             , label = "X brake labels (,)"
+                           )
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           textInput(
+                             inputId ="raw_opt"
+                             , label = "Opt"
+                             , placeholder = "extra layers"
+                           )
+                           
+                    )
+                  )
+                  
+           )
+         )
+         
+),
 
 # Yupana Analysis ---------------------------------------------------------
 # -------------------------------------------------------------------------
 
-                    ),
-
-            tabPanel("Analysis",
-
-
-                     fluidRow(
-
-                       column(2,
-
-                              radioButtons(inputId = "rpt_preview_opt"
-                                           , label = "Modules"
-                                           , choices = c("Gsheet"
-                                                         , "Model"
-                                                         , "Diagnostic" = "Plots")
-                                           , inline = TRUE
-                                           , selected = "Model"
-
-                              ),
-
-                              uiOutput("rpt_variable"),
-
-                              uiOutput("rpt_dotplot_groups"),
-                              
-                              uiOutput("sheet_export"),
-                              
-                              uiOutput("rpt_digits"),
-                              
-                              br(),
-                              
-                              actionButton(inputId = "fbsm_refresh"
-                                           , label = "Refresh"
-                                           , class = "btn btn-success"
-                              )
-
-                              ),
-
-
-                       column(width = 10,
-
-                                uiOutput("rpt_preview")
-
-                       ),
-
-                     )
+tabPanel("Analysis",
+         
+fluidRow(
+  
+  column(2, 
+                
+        radioButtons(inputId = "analysis_preview_opt"
+                     , label = "Modules"
+                     , choices = c("Gsheet"
+                                   , "Model"
+                                   , "Diagnostic"
+                                   )
+                     , inline = TRUE
+                     , selected = "Model"
+                     ),
+        
+        uiOutput("analysis_last_factor"),
+        
+        uiOutput("analysis_response"),
+        
+        uiOutput("analysis_comparison"),
+        
+        uiOutput("analysis_model_factors"),
 
+        selectInput(
+          inputId = "analysis_test_comparison"
+          , label = "Test comparison"
+          , choices = c("SNK", "TUKEY", "DUNCAN")
+        ),
+        
+        fluidRow(
+          
+          column(7,
+                 
+                 numericInput(
+                   inputId = "analysis_sig_level"
+                   , label = "Significance level"
+                   , value = 0.05
+                   , step = 0.01
+                   , min = 0
+                   , max = 0.5
+                 )
+                 
+          ),
+          
+          column(5,
+                 
+                 numericInput(
+                   inputId = "analysis_digits"
+                   , label = "Digits"
+                   , value = 2
+                   , min = 0
+                   , step = 1
+                 )
+                 
+          )
+          
+        )
+        
+        ),
+ 
+ column(10,
+        
+        uiOutput("analysis_preview")
+        
+        )
+ 
+ )
+                     
+         
 # Yupana Graphics ---------------------------------------------------------
 # -------------------------------------------------------------------------
 
-            ),
+),
 
-           tabPanel("Graphics",
+tabPanel("Graphics",
+         
+         fluidRow(
+           
+           column(2,
 
-                    fluidRow(
+                  fixedRow(
 
-                      column(2,
+                    column(12,
+                           
+                           radioButtons(inputId = "smr_preview_opt"
+                                        , label = "Modules"
+                                        , choices = c("Gsheet"
+                                                      , "Plots")
+                                        , selected = "Plots"
+                                        , inline = TRUE)
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("smr_type")
+                           
+                           ),
+                           
 
-                             radioButtons(inputId = "grp_preview_opt"
-                                          , label = "Modules"
-                                          , choices = c("Gsheet"
-                                                        , "Plots")
-                                          , selected = "Plots"
-                                          , inline = TRUE
+                    column(12,
 
-                             ),
+                           uiOutput("smr_response")
 
-                             uiOutput("graph_sheets"),
+                           ),
 
-                             numericInput(inputId = "graph_width"
-                                          , label = "Width (cm)"
-                                          , value = 20
-                                          , step = 2
-                                          , min = 5
-                             ),
+                    column(12,
 
-                             numericInput(inputId = "graph_height"
-                                          , label = "Height (cm)"
-                                          , value = 10
-                                          , step = 2
-                                          , min = 5
-                             ),
+                           uiOutput("smr_x")
 
-                             numericInput(inputId = "graph_dpi"
-                                          , label = "Resolution"
-                                          , value = 100
-                                          , step = 20
-                                          , min = 50
-                             ),
-                             
-                             
-                             fluidRow(
-                               
-                               column(6, 
-                                      
-                                      div(
-                                        
-                                        actionButton(inputId = "graph_refresh"
-                                                     , label = "Refresh"
-                                                     , class = "btn btn-warning")
-                                        
-                                        , align = "center")
-                                      
+                           ),
 
-                                      ),
-                               
-                               column(6, 
-                                      
-                                      div(
-                                        
-                                        actionButton(inputId = "graph_create"
-                                                     , label = "Create"
-                                                     , class = "btn btn-success")
-                                        
-                                        , align = "center")
-                                      
-                                      )
-                             ),
-                             
-                             ),
+                    column(12,
 
-                      column(width = 10,
-
-                               uiOutput("graph_preview")
-
-                      ),
+                           uiOutput("smr_group")
 
+                           ),
+                    
+                    column(6, 
+                           
+                           uiOutput("smr_sig")
+                           
+                           ),
+                    
+                    column(6, 
+                           
+                           uiOutput("smr_error")
+                           
+                    ),
+                    
+                    column(6, 
+                           
+                           uiOutput("smr_ylimits")
+                           
+                    ),
+                    
+                    column(6, 
+                           
+                           uiOutput("smr_xrotation")
+                           
+                    ),
+                    
+                    column(12,
+                           
+                           uiOutput("smr_dimension")
+                           
+                    ),
+                    
+                    column(6,
+                           
+                           uiOutput("graph_sheet_save"),
+                           
+                           ),
+                    
+                    column(6,
+                           
+                           radioButtons(inputId = "graph_smr_overwrite"
+                                        , label = "Overwrite"
+                                        , inline = TRUE
+                                        , choices = c("no", "yes")
+                                        )
+                           ),
+                    
+                    column(6,
+                           
+                           actionButton(inputId = "graph_smr_load"
+                                        , label = "Load"
+                                        , class = "btn btn-primary"
+                                        , width = "100%"
+                                        )
+                           
+                           ),
+                    
+                    column(6,
+                           
+                           actionButton(inputId = "graph_smr_save"
+                                        , label = "Save"
+                                        , class = "btn btn-warning"
+                                        , width = "100%"
+                                        )
+                           
+                           ),
+                    
+                    br(),
+                    br()
+                    
                     )
+                  
+           ),
+           
+           column(8,
+                  
+                  uiOutput("plot_smr"),
+                  
+           ),
+           
+           column(2,
+                  
+                  fixedRow(
+                    
+                    column(12,
+                           
+                           HTML('<p>Model</p>'),
+                           
+                           verbatimTextOutput("analysis_model")
+                           
+                    ),
+                    
+                    column(6, 
+                           
+                           uiOutput("plot_color"),
+                           
+                           ),   
+                    
+                    column(6, 
+                           
+                           uiOutput("plot_error"),
+                           
+                           ),
+                    
+                    column(12, 
+                           
+                           uiOutput("plot_ylab")
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("plot_xlab")
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("plot_glab")
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("plot_gtext")
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           uiOutput("plot_xtext")
+                           
+                    ),
+                    
+                    column(12, 
+                           
+                           
+                           uiOutput("plot_opt")
+                           
+                           )
+                  )
+                  
+           )
+         )
+                    
+# multivariate ------------------------------------------------------------
+# -------------------------------------------------------------------------
 
-                ),
+),
 
         tabPanel("Multivariate",
 
@@ -475,40 +767,25 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
                                                      , "CORR"
                                                      )
                                        , inline = TRUE
-
-                          ),
+                                       ),
+                          
+                          uiOutput("mvr_last_factor"),
 
                           uiOutput("mvr_facts"),
 
                           uiOutput("mvr_groups"),
+                          
+                          uiOutput("mvr_variables"),
 
-                          numericInput(inputId = "mvr_width"
-                                       , label = "Width (cm)"
-                                       , value = 15
-                                       , step = 2
-                                       , min = 5
+                          textInput(
+                            inputId ="mvr_dimension"
+                            , label = "Dimensions (cm)"
+                            , placeholder = "w*h*dpi"
+                            , value = "14*14*100"
+                            )
+                          
                           ),
 
-                          numericInput(inputId = "mvr_height"
-                                       , label = "Height (cm)"
-                                       , value = 15
-                                       , step = 2
-                                       , min = 5
-                          ),
-
-                          numericInput(inputId = "mvr_dpi"
-                                       , label = "Resolution"
-                                       , value = 100
-                                       , step = 20
-                                       , min = 50
-                          ),
-
-                          actionButton(inputId = "mvr_refresh"
-                                       , label = "Refresh"
-                                       , class = "btn btn-success"
-                          )
-                   ),
-
                    column(width = 10,
 
                           uiOutput("mvr_preview")
@@ -518,7 +795,39 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
                   br()
 
                  )
-        )
+        ),
+
+# Yupana Fieldbook --------------------------------------------------------
+# -------------------------------------------------------------------------
+
+tabPanel("Fieldbook",
+         
+         fluidRow(
+           
+           column(2,
+                  
+                  radioButtons(inputId = "fb_preview_opt"
+                               , label = "Modules"
+                               , choices = c("Reshape")
+                               , inline = TRUE
+                               
+                  ),
+                  
+                  uiOutput("fb_modules"),
+                  
+                  br(),
+                  
+           ),
+           
+           column(width = 10,
+                  
+                  uiOutput("fieldbook_preview")
+                  
+           ),
+           
+         )
+         
+)
 
 # Yupana end code ---------------------------------------------------------
 # -------------------------------------------------------------------------
